/*
 *  TrayMessage.cs
 *  Copyright (C) 2006-2007 Marcin Krystian Krzywonos
 *  License: GNU/GPL, version 2
 */


using System;
using System.Reflection;
using System.Collections;
using Mono.Unix;
using GLib;


namespace Incollector.GUI.Widgets {
	public enum MsgType {
		Info,
		Question,
		Error,
		Warning
	}
	
	
	public class TrayMessage {
		private  Gtk.Window  window;
		private Gtk.Viewport view;
		
		
		public TrayMessage (MsgType type, bool ShowCloseBtn, Gtk.Button btn1, Gtk.Button btn2, string title, string message)
		{
			window = new Gtk.Window (Gtk.WindowType.Toplevel);
			window.TypeHint = Gdk.WindowTypeHint.Normal;
			window.Stick ();
			window.KeepAbove = true;
			window.SkipTaskbarHint = true;
			window.Decorated = false;
			
			view = new Gtk.Viewport ();
			view.ModifyBg (Gtk.StateType.Normal , new Gdk.Color (255, 255, 255));
			window.Add (view);
			
			Gtk.HBox WindowBox = new Gtk.HBox ();
			WindowBox.Spacing = 12;
			WindowBox.BorderWidth = 12;
			view.Add (WindowBox);
			
			Gtk.Image icon = new Gtk.Image ();
			switch (type) {
				case MsgType.Error   : icon = new Gtk.Image (new Gdk.Pixbuf (Assembly.GetEntryAssembly (), "Error-48.png"));    break;
				case MsgType.Info    : icon = new Gtk.Image (new Gdk.Pixbuf (Assembly.GetEntryAssembly (), "Info-48.png"));     break;
				case MsgType.Question: icon = new Gtk.Image (new Gdk.Pixbuf (Assembly.GetEntryAssembly (), "Question-48.png")); break;
				case MsgType.Warning : icon = new Gtk.Image (new Gdk.Pixbuf (Assembly.GetEntryAssembly (), "Warning-48.png"));  break;
			}
			WindowBox.Add (icon);
			
			Gtk.VBox LabelsBox = new Gtk.VBox ();
			LabelsBox.Spacing  = 6;
			WindowBox.PackStart (LabelsBox, false, true, 0);
			
			if (title.Length > 0) {
				Gtk.Label TitleLabel = new Gtk.Label ();
				TitleLabel.UseMarkup = true;
				TitleLabel.Wrap      = true;
				TitleLabel.Xalign    = (float) 0.00;
				TitleLabel.Markup    = "<span weight=\"bold\" size=\"larger\">" + title + "</span>";
				TitleLabel.WidthRequest = 300;
				LabelsBox.Add (TitleLabel);
			}
			
			if (message.Length > 0) {
				Gtk.Label MessageLabel    = new Gtk.Label ();
				MessageLabel.UseMarkup    = true;
				MessageLabel.Markup       = message;
				MessageLabel.Xalign       = (float) 0.00;
				MessageLabel.Wrap         = true;
				MessageLabel.WidthRequest = 300;
				LabelsBox.Add (MessageLabel);
			}
			
			Gtk.HButtonBox ButtonsBox = new Gtk.HButtonBox ();
			ButtonsBox.Layout         = Gtk.ButtonBoxStyle.End;
			ButtonsBox.Spacing        = 6;
			LabelsBox.Add (ButtonsBox);
			
			if (btn1 != null) {
				btn1.Relief = Gtk.ReliefStyle.None;
				ButtonsBox.Add (btn1);
			}
			
			if (btn2 != null) {
				btn2.Relief = Gtk.ReliefStyle.None;
				ButtonsBox.Add (btn2);
			}
			
			if (ShowCloseBtn == true) {
				Gtk.Button ExitBtn      = new Gtk.Button ();
				Gtk.Label  ExitBtnLabel = new Gtk.Label ();
				ExitBtnLabel.UseMarkup  = true;
				ExitBtnLabel.Markup     = "<span color=\"#1111EE\">" + Catalog.GetString ("Close") + "</span>";
				ExitBtn.Relief          = Gtk.ReliefStyle.None;
				ExitBtn.Clicked        += new EventHandler (on_ExitBtn_clicked);
				ExitBtn.Add (ExitBtnLabel);
				ButtonsBox.Add (ExitBtn);
			}
			
			WindowBox.ShowAll ();
		}
		

		private void on_ExitBtn_clicked (object o, EventArgs args)
		{
			this.Hide ();
		}
		
		
		public void Show ()
		{
			window.Move (30, 30);
			window.ShowAll ();
			window.Sensitive = true;
		}
		
		
		public void Hide ()
		{
			window.Destroy ();
		}
	}
}
