/*
 *  Types/Conversation.cs
 *  Copyright (C) 2006-2007 Marcin Krystian Krzywonos
 *  License: GNU/GPL version 2
 */


using System;
using System.Xml;
using System.Reflection;
using Incollector.GUI.Widgets;
using Gtk;
using Mono.Unix;


namespace Incollector.DataTypes {
	
	public class Conversation : DataType {
		
		protected static Gtk.Entry    TitleWidget = new Gtk.Entry ();
		protected static Gtk.TextView TextWidget  = new Gtk.TextView ();
		
		protected string _DataTitle = "";
		protected string _DataText = "";
		
		protected string DataTitle {
			get { return this._DataTitle;  }
			set { this._DataTitle = value; }
		}
		
		protected string DataText {
			get { return this._DataText;  }
			set { this._DataText = value; }
		}
		
		
		
		public override string Name {
			get { return "conversation"; }
		}
		
		public override string Title {
			get { return Catalog.GetString ("Conversation"); }
		}
		
		public override string MenuText {
			get { return Catalog.GetString ("Add a conversation log"); }
		}
		
		public override Gtk.Widget DefaultFocusWidget {
			get { return TitleWidget; }
		}
		
		public override Gtk.Widget EditWidget  {
			get {
				Gtk.Table tbl = new Gtk.Table (2, 2, false);
				
				Gtk.Label lbl1 = new Gtk.Label (Catalog.GetString ("Title"));
				lbl1.Xalign = 1;
				lbl1.Yalign = (float) 0.50;
				tbl.Attach (lbl1, 0, 1, 0, 1, AttachOptions.Fill,
							AttachOptions.Fill, 3, 3);
				
				TitleWidget = new Gtk.Entry ();
				TitleWidget.Text = this.DataTitle;
				Incollector.Engine.Autocompletion.Assign (TitleWidget, "data:" + Name + ":Title");
				tbl.Attach (TitleWidget, 1, 2, 0, 1,
							AttachOptions.Expand | AttachOptions.Fill,
							AttachOptions.Shrink | AttachOptions.Fill, 3, 3);
				
				Gtk.Label lbl2 = new Gtk.Label (Catalog.GetString ("Conversation"));
				lbl2.Xalign = 1;
				lbl2.Yalign = 0;
				tbl.Attach (lbl2, 0, 1, 1, 2, AttachOptions.Fill,
							AttachOptions.Fill, 3, 3);
				
				TextWidget = new Gtk.TextView ();
				TextWidget.Buffer.Text = this.DataText;
				TextWidget.HeightRequest = 150;
				TextWidget.AcceptsTab = false;
				TextWidget.WrapMode = Gtk.WrapMode.Word;
				TextWidget.PixelsAboveLines = 1;
				TextWidget.LeftMargin = 3;
				TextWidget.RightMargin = 3;
				
				Gtk.ScrolledWindow scroll = new Gtk.ScrolledWindow ();
				scroll.SetPolicy (Gtk.PolicyType.Automatic, Gtk.PolicyType.Automatic); 
				scroll.ShadowType = Gtk.ShadowType.In; 
				scroll.Add (TextWidget);
				tbl.Attach (scroll, 1, 2, 1, 2,
							AttachOptions.Expand | AttachOptions.Fill,
							AttachOptions.Expand | AttachOptions.Fill, 3, 3);
				
				tbl.ShowAll ();
				
				return tbl;
			}
		}
		
		public override string EditWidgetContent  {
			set { this.DataText = value; }
		}
		
		public override Gtk.Widget FocusWidget {
			get { return TitleWidget; }
		}
		
		public override Gtk.Widget PreviewWidget {
			get {
				Gtk.Table tbl = new Gtk.Table (2, 2, false);
				
				Gtk.Label lbl1 = new Gtk.Label ();
				lbl1.UseMarkup = true;
				lbl1.Markup    = "<b>" + Catalog.GetString ("Title") + "</b>";
				lbl1.Xalign    = 1;
				lbl1.Yalign    = 0;
				tbl.Attach (lbl1, 0, 1, 0, 1, AttachOptions.Fill,
							AttachOptions.Fill, 3, 3);
				
				PreviewLabel LabelTitle  = new PreviewLabel (DataTitle);
				LabelTitle.Xalign     = 0;
				LabelTitle.Yalign     = 0;
				
				tbl.Attach (LabelTitle, 1, 2, 0, 1,
							AttachOptions.Fill,
							AttachOptions.Fill, 3, 3);
				
				Gtk.Label lbl2 = new Gtk.Label ();
				lbl2.UseMarkup = true;
				lbl2.Markup    = "<b>" + Catalog.GetString ("Conversation") + "</b>";
				lbl2.Xalign    = 1;
				lbl2.Yalign    = 0;
				tbl.Attach (lbl2, 0, 1, 1, 2, AttachOptions.Fill,
							AttachOptions.Fill, 3, 3); 
				
				PreviewLabel LabelConversation = new PreviewLabel (DataText);
				LabelConversation.Wrap = true;
				LabelConversation.Xalign = 0;
				LabelConversation.Yalign = 0;
				tbl.Attach (LabelConversation, 1, 2, 1, 2,
							AttachOptions.Expand | AttachOptions.Fill,
							AttachOptions.Expand | AttachOptions.Fill, 3, 3);
				
				tbl.ShowAll ();
				
				return tbl;
			}
		}
		
		public override string EntryTitle {
			get { return DataTitle; }
		}
		
		public override Gdk.Pixbuf Icon16 {
			get { return new Gdk.Pixbuf (Assembly.GetEntryAssembly (), "conversation-16.png"); }
		}
		
		public override Gdk.Pixbuf Icon32 {
			get { return new Gdk.Pixbuf (Assembly.GetEntryAssembly (), "conversation-32.png"); }
		}
		
		public override Gdk.Pixbuf Icon48 {
			get { return new Gdk.Pixbuf (Assembly.GetEntryAssembly (), "conversation-48.png"); }
		}
		
		
		
		public Conversation ()
		{
		}
		
		
		public override DataType New ()
		{
			return new Conversation ();
		}
		
		
		public override DataType Clone ()
		{
			Conversation cnv = new Conversation ();
			
			cnv.DataText = this.DataText.Clone () as string;
			cnv.DataTitle = this.DataTitle.Clone () as string;
			
			return cnv;
		}
		
		
		public override void ReadXml (XmlTextReader reader)
		{
			this.DataTitle = reader.GetAttribute ("title");
			this.DataText  = reader.ReadString ();
			
			Incollector.Engine.Autocompletion.Add ("data:" + Name + ":Title", this.DataTitle);
		}
		
		
		public override void WriteXml (XmlTextWriter writer)
		{
			writer.WriteStartElement (Name);
				writer.WriteAttributeString ("title", this.DataTitle);
				writer.WriteString (this.DataText);
			writer.WriteEndElement ();
		}
		
		
		public override void AddChangedEvent (EventHandler hdlr)
		{
			TitleWidget.Changed        += hdlr;
			TextWidget.Buffer.Changed  += hdlr;
		}
		
		
		public override bool Search (string query)
		{
			return Engine.Text.Search (query, this.DataTitle) || Engine.Text.Search (query, this.DataText);
		}
		
		
		public override bool IsFormFilledIn ()
		{
			return (TitleWidget.Text != "") && (TextWidget.Buffer.Text != "");
		}
		
		
		public override void SynchronizeData ()
		{
			this.DataTitle = TitleWidget.Text;
			this.DataText  = TextWidget.Buffer.Text;
		}
	}
}
